@@ -1,6 +1,11 @@
 from aitoolbox.torchtrain.model import TTModel, MultiGPUModelWrap, ModelWrap
 from aitoolbox.torchtrain.parallel import TTDataParallel
-from aitoolbox.torchtrain.train_loop import TrainLoop, TrainLoopCheckpoint, TrainLoopEndSave, TrainLoopCheckpointEndSave
+from aitoolbox.torchtrain.train_loop.train_loop import TrainLoop
+from aitoolbox.torchtrain.train_loop.train_loop_tracking import (
+    TrainLoopCheckpoint,
+    TrainLoopEndSave,
+    TrainLoopCheckpointEndSave
+)
 from aitoolbox.torchtrain.data.batch_model_feed_defs import AbstractModelFeedDefinition
 from aitoolbox.torchtrain.multi_loss_optim import MultiLoss, MultiOptimizer
 
