@@ -1,11 +1,6 @@
 import functools
 import torch.nn as nn
 from torch.nn.parallel import DistributedDataParallel
-try:
-    from deepspeed import DeepSpeedLight
-    DEEPSPEED_AVAILABLE = True
-except ImportError:
-    DEEPSPEED_AVAILABLE = False
 
 from aitoolbox.utils.util import copy_function
 
@@ -80,24 +75,3 @@ class TTDistributedDataParallel(DistributedDataParallel, TTParallelBase):
         """
         DistributedDataParallel.__init__(self, module, **kwargs)
         TTParallelBase.__init__(self, module, default_model_methods)
-
-
-if DEEPSPEED_AVAILABLE:
-    class TTDeepSpeedLight(DeepSpeedLight, TTParallelBase):
-        def __init__(self, args, model,
-                     default_model_methods=('get_loss', 'get_loss_eval', 'get_predictions'),
-                     **kwargs):
-            """torchtrain enabled Microsoft DeepSpeed's DeepSpeedLight engine
-
-            Args:
-                args (argparse.Namespace): argparser results structured as per DeepSpeed requirements. A dictionary
-                    containing local_rank and deepspeed_config file location.
-                model (aitoolbox.torchtrain.model.TTModel): neural network model
-                default_model_methods (list or tuple): list of core methods which are present also in TTModel
-                    abstract class
-                **kwargs: additional parameters for the underlying ``deepspeed.DeepSpeedLight`` class
-
-                    Possible arguments: https://deepspeed.readthedocs.io/en/latest/initialize.html
-            """
-            DeepSpeedLight.__init__(self, args, model, **kwargs)
-            TTParallelBase.__init__(self, model, default_model_methods)
